==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/messages/an/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> acción',
    '<strong>Latest</strong> updates' => '<strong>Zagueras</strong> actividatz',
    '<strong>Mail</strong> summary' => 'Resumen d\'o <strong>correu</strong>',
    'Administration' => 'Administración',
    'All' => 'Tot',
    'Allow' => 'Permitir',
    'An error occurred while handling your last action. (Handler not found).' => 'Ha ocurriu un error procesando a tuya zaguera acción. (Handler no trobau).',
    'An unexpected error occurred while loading the search result.' => 'Ha ocurriu un error inasperau mientres se cargaban os resultaus de busca.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ha ocurriu un error inasperau. Si contina pasando, per favor contacta con l\'administrador d\'o sistema.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ha ocurriu un error inesperau en o servidor web. Si contina pasando, per favor contacta con l\'administrador d\'o sistema.',
    'Back' => 'Tornar',
    'Back to dashboard' => 'Tornar a Encieto',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Cambiar luenga',
    'Close' => 'Zarrar',
    'Collapse' => 'Zarrar',
    'Confirm' => 'Confirmar',
    'Copy to clipboard' => 'Copiar a o puertafuellas.',
    'Default' => 'Defecto',
    'Delete' => 'Eliminar',
    'Deny' => 'Denegar',
    'Do you really want to perform this action?' => 'Yes seguro de querer fer ista acción?',
    'Edit' => 'Editar',
    'Error' => 'Error',
    'Error:' => 'Error:',
    'Expand' => 'Esbandir',
    'Export' => 'Exportar:',
    'Info:' => 'Información:',
    'It looks like you may have taken the wrong turn.' => 'Pareixe que has tomau o camín incorrecto.',
    'Language' => 'Luenga',
    'Loading...' => 'Cargando...',
    'Login' => 'Inicio de sesión',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Zarrar sesión',
    'Menu' => 'Menú',
    'New profile image' => 'Nueva imachen de perfil',
    'Next' => 'Siguient',
    'No error information given.' => 'No s\'ha dau garra información.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Ubrir',
    'Please type at least 3 characters' => 'Per favor escribe a lo menos 3 caracteres',
    'Profile dropdown' => 'Menú d\'o perfil',
    'Profile picture of {displayName}' => 'Imachen de portalada de {displayName}',
    'Save' => 'Alzar',
    'Saved' => 'Alzau',
    'Search' => 'Buscar',
    'Select Me' => 'Seleccionar-me',
    'Settings' => 'Achustes',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar mas',
    'Some files could not be uploaded:' => 'Bells ficheros no s\'han puesto puyar-se:',
    'Text could not be copied to clipboard' => 'O texto no s\'ha puesto copiar a o portapapers.',
    'Text has been copied to clipboard' => 'O texto ha estau copiau a o portapapers.',
    'The date has to be in the past.' => 'A calendata ha d\'estar en pasau.',
    'The file has been deleted.' => 'O fichero ha estau borrau.',
    'The requested resource could not be found.' => 'O recurso solicitau no ha puesto ser cargau.',
    'The space has been archived.' => 'O espacio ha estau archivau.',
    'The space has been unarchived.' => 'O espacio ha estau desarchivau.',
    'Time Zone' => 'Huso horario.',
    'Unsubscribe' => 'Desubscribir-se',
    'Upload' => 'Puyar',
    'Upload file' => 'Puyar fichero',
    'Actions' => '',
    'Add:' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '',
    'Could not find content of addon!' => '',
    'Could not find requested page.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Error while running your last action (Invalid request method).' => '',
    'Invalid request method!' => '',
    'Module is not enabled on this content container!' => '',
    'My Profile' => '',
    'No results' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'You are not allowed to run this action.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/an/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> acción',
    '<strong>Latest</strong> updates' => '<strong>Zagueras</strong> actividatz',
    '<strong>Mail</strong> summary' => 'Resumen d\'o <strong>correu</strong>',
    'Administration' => 'Administración',
    'All' => 'Tot',
    'Allow' => 'Permitir',
    'An error occurred while handling your last action. (Handler not found).' => 'Ha ocurriu un error procesando a tuya zaguera acción. (Handler no trobau).',
    'An unexpected error occurred while loading the search result.' => 'Ha ocurriu un error inasperau mientres se cargaban os resultaus de busca.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ha ocurriu un error inasperau. Si contina pasando, per favor contacta con l\'administrador d\'o sistema.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ha ocurriu un error inesperau en o servidor web. Si contina pasando, per favor contacta con l\'administrador d\'o sistema.',
    'Back' => 'Tornar',
    'Back to dashboard' => 'Tornar a Encieto',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Cambiar luenga',
    'Close' => 'Zarrar',
    'Collapse' => 'Zarrar',
    'Confirm' => 'Confirmar',
    'Copy to clipboard' => 'Copiar a o puertafuellas.',
    'Default' => 'Defecto',
    'Delete' => 'Eliminar',
    'Deny' => 'Denegar',
    'Do you really want to perform this action?' => 'Yes seguro de querer fer ista acción?',
    'Edit' => 'Editar',
    'Enter security code above' => 'Mete o codigo de seguranza aquí',
    'Error' => 'Error',
    'Error:' => 'Error:',
    'Expand' => 'Esbandir',
    'Export' => 'Exportar:',
    'Info:' => 'Información:',
    'It looks like you may have taken the wrong turn.' => 'Pareixe que has tomau o camín incorrecto.',
    'Language' => 'Luenga',
    'Loading...' => 'Cargando...',
    'Login' => 'Inicio de sesión',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Zarrar sesión',
    'Menu' => 'Menú',
    'New profile image' => 'Nueva imachen de perfil',
    'Next' => 'Siguient',
    'No error information given.' => 'No s\'ha dau garra información.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Ubrir',
    'Please type at least 3 characters' => 'Per favor escribe a lo menos 3 caracteres',
    'Profile dropdown' => 'Menú d\'o perfil',
    'Profile picture of {displayName}' => 'Imachen de portalada de {displayName}',
    'Save' => 'Alzar',
    'Saved' => 'Alzau',
    'Search' => 'Buscar',
    'Select Me' => 'Seleccionar-me',
    'Settings' => 'Achustes',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar mas',
    'Some files could not be uploaded:' => 'Bells ficheros no s\'han puesto puyar-se:',
    'Text could not be copied to clipboard' => 'O texto no s\'ha puesto copiar a o portapapers.',
    'Text has been copied to clipboard' => 'O texto ha estau copiau a o portapapers.',
    'The date has to be in the past.' => 'A calendata ha d\'estar en pasau.',
    'The file has been deleted.' => 'O fichero ha estau borrau.',
    'The requested resource could not be found.' => 'O recurso solicitau no ha puesto ser cargau.',
    'The space has been archived.' => 'O espacio ha estau archivau.',
    'The space has been unarchived.' => 'O espacio ha estau desarchivau.',
    'Time Zone' => 'Huso horario.',
    'Unsubscribe' => 'Desubscribir-se',
    'Upload' => 'Puyar',
    'Upload file' => 'Puyar fichero',
    'Actions' => '',
    'Add:' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Back to login' => '',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => '',
    'Could not find content of addon!' => '',
    'Could not find requested page.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Error while running your last action (Invalid request method).' => '',
    'I\'m not a robot' => '',
    'Invalid request method!' => '',
    'Module is not enabled on this content container!' => '',
    'My Profile' => '',
    'No results' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Switch network' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
    'You are not allowed to run this action.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
